[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[for-4.17] automation: Do not use null scheduler for boot cpupools test


  • To: <xen-devel@xxxxxxxxxxxxxxxxxxxx>
  • From: Michal Orzel <michal.orzel@xxxxxxx>
  • Date: Fri, 21 Oct 2022 18:53:41 +0200
  • Arc-authentication-results: i=1; mx.microsoft.com 1; spf=pass (sender ip is 165.204.84.17) smtp.rcpttodomain=lists.xenproject.org smtp.mailfrom=amd.com; dmarc=pass (p=quarantine sp=quarantine pct=100) action=none header.from=amd.com; dkim=none (message not signed); arc=none
  • Arc-message-signature: i=1; a=rsa-sha256; c=relaxed/relaxed; d=microsoft.com; s=arcselector9901; h=From:Date:Subject:Message-ID:Content-Type:MIME-Version:X-MS-Exchange-AntiSpam-MessageData-ChunkCount:X-MS-Exchange-AntiSpam-MessageData-0:X-MS-Exchange-AntiSpam-MessageData-1; bh=fIPnwdLEH/hxki/6fg7zi/AAYz+XnzsGm7q1VuCQFho=; b=iKn4sEtXE8sPWK5+cYJ73xBAb5LMG9k+c6kR9qKop6t26KJKpva25USEuGnZ2bD2aIZc6f6AqKLmdx0d4CJOf4Ac7zJZabqyHccgB5B5gHZFWvY45oU2tjQZ03P0pnkj7yXNiPEGUpbXq5KuTSJrJ9AW58ir8HYJ7DGlDogJKy5ginjR98FpgE/kZGodj9j4edAyq8w5yIVHplePy8ZVwqm+VS46OuU3DT1pTzTX/b1k7xyDt3Jagz80AyzjUHt4iYnJ02Scb/ryJJzKUCI5H0PKw/4JBtzKA+Vn5LUUKNPxLnT62/2HAMpFC+mvuqz6EXXhAzJUX3fiq7HN+Etpew==
  • Arc-seal: i=1; a=rsa-sha256; s=arcselector9901; d=microsoft.com; cv=none; b=S4Skq+tL9ZrTeaWtwvK2Wai7pV/XJXb2ufOYnA7caGBL2jpP7N/79CRpVGF7alycepzvP1KF1vgDTrMY+8x0nRUwMx6y9GNSXqAkhI7lE6tWlByJlOBfwh1ZBR8Nf0gYWEtNKlfpKFazkOHu/JNI5bStxV7X7ytT8YqQCG6ZI/MGKo78Y5iHt4/TK2uvAh4cJ4gxdUeji6c32vlN+dNaqFlKSU58gZ+wwNIgEwC+sjM7ZEYipaONaGu/0C4/mFPDR7pa3qpvJ1mdbGb1n/yvV9my6E2erd8XxNKKpItgxJRvQBbOVEPqmCtdTLlBg7iYGzCOeYtqrcFp+O0PkKGwag==
  • Cc: Michal Orzel <michal.orzel@xxxxxxx>, Doug Goldstein <cardoe@xxxxxxxxxx>, Stefano Stabellini <sstabellini@xxxxxxxxxx>, Henry Wang <Henry.Wang@xxxxxxx>
  • Delivery-date: Fri, 21 Oct 2022 16:53:54 +0000
  • List-id: Xen developer discussion <xen-devel.lists.xenproject.org>

Null scheduler is not enabled on non-debug Xen builds so the current
test can lead to a failure on such jobs. We still want to test that we
can assign the cpupool to a domU with a different scheduler than default
one (credit2). Switch to credit as it is enabled by default.

Fixes: 36e3f4158778 ("automation: Add a new job for testing boot time cpupools 
on arm64")
Signed-off-by: Michal Orzel <michal.orzel@xxxxxxx>
---
This patch acts as a prerequisite before merging the following patch:
https://lore.kernel.org/xen-devel/20221021132238.16056-1-michal.orzel@xxxxxxx/
(to which Henry already gave RAB), that helped to find the issue described
in the comment.
---
 automation/scripts/qemu-smoke-arm64.sh | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/automation/scripts/qemu-smoke-arm64.sh 
b/automation/scripts/qemu-smoke-arm64.sh
index 5b566072f72a..a5d8d135b659 100755
--- a/automation/scripts/qemu-smoke-arm64.sh
+++ b/automation/scripts/qemu-smoke-arm64.sh
@@ -29,10 +29,10 @@ fi
 fi
 
 if [[ "${test_variant}" == "boot-cpupools" ]]; then
     # Check if domU0 (id=1) is assigned to Pool-1 with null scheduler
     passed="${test_variant} test passed"
     dom0_check="
-if xl list -c 1 | grep -q Pool-1 && xl cpupool-list Pool-1 | grep -q Pool-1; 
then
+if xl list -c 1 | grep -q Pool-1 && xl cpupool-list Pool-1 | grep -q credit; 
then
     echo ${passed}
 fi
 "
@@ -140,7 +140,7 @@ fi
 
 if [[ "${test_variant}" == "boot-cpupools" ]]; then
     echo '
-CPUPOOL[0]="cpu@1 null"
+CPUPOOL[0]="cpu@1 credit"
 DOMU_CPUPOOL[0]=0
 NUM_CPUPOOLS=1' >> binaries/config
 fi
@@ -29,10 +29,10 @@ fi
 
 if [[ "${test_variant}" == "boot-cpupools" ]]; then
-    # Check if domU0 (id=1) is assigned to Pool-1 with null scheduler
+    # Check if domU0 (id=1) is assigned to Pool-1 with credit scheduler
     passed="${test_variant} test passed"
     dom0_check="
-- 
2.25.1




 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.